@@ -1,4 +1,4 @@
-from koco.about import __version__, __description__  # noqa: F401
 from koco.load import list_datasets, load_dataset  # noqa: F401
 
 from koco import korean_hate_speech  # noqa: F401
+from koco import sae4k  # noqa: F401
