@@ -1,10 +1,9 @@
 import logging
+import importlib
 import requests
 
 from .patch import download_dataset
-from .utils import DOWNLOAD_DIR, exist_dataset
-from .korean_hate_speech import load as khs_loader
-
+from .utils import dataset_to_module_name, DOWNLOAD_DIR, exist_dataset
 
 KOCOHUB = 'https://api.github.com/orgs/kocohub/repos'
 
@@ -13,12 +12,26 @@ logger = logging.getLogger(__name__)
 
 def list_datasets():
     """List datasets in kocohub
+
+    Returns:
+        dataset (dict): dataset name and its available mode
+            {
+                'korean-hate-speech': ['labeled', 'unlabeled', 'testset'],
+                ...
+            }
     """
     success = False
     while not success:
-        r = requests.get(KOCOHUB, params={'per_page': '500'})
+        r = requests.get(KOCOHUB, params={'per_page': '500'})  # TODO: if dataset > 500, then fix
         success = r.ok
-    return [info['name'] for info in r.json()]
+    dataset_names = [info['name'] for info in r.json()]
+
+    dataset = dict()
+    for d_name in dataset_names:
+        module_name = dataset_to_module_name(d_name)
+        modes = importlib.import_module(f'koco.{module_name}').AVAILABLE_MODE
+        dataset[d_name] = list(modes.keys())
+    return dataset
 
 
 def is_valid_dataset(dataset):
@@ -48,5 +61,7 @@ def patch_dataset(dataset, verbose=True):
 def load_dataset(dataset, mode, verbose=True):
     patch_dataset(dataset, verbose)
 
-    if dataset == 'korean-hate-speech':
-        return khs_loader(mode)
+    # NOTE: module name should be same with dataset name
+    module_name = dataset_to_module_name(dataset)
+    loader = importlib.import_module(f'koco.{module_name}').load
+    return loader(mode)
